dbaccess/source/ui/browser/sbagrid.cxx                   |    6 +++---
 dbaccess/source/ui/misc/WCPage.cxx                       |    2 +-
 embeddedobj/source/msole/oleembed.cxx                    |    2 +-
 odk/examples/DevelopersGuide/Forms/ButtonOperator.java   |    2 +-
 odk/examples/DevelopersGuide/Forms/FLTools.java          |    2 +-
 odk/examples/java/Text/BookmarkInsertion.java            |    2 +-
 qadevOOo/runner/util/utils.java                          |    4 ++--
 qadevOOo/tests/java/ifc/sheet/_TableAutoFormatField.java |    2 +-
 starmath/source/mathmlimport.cxx                         |    2 +-
 starmath/source/mathtype.cxx                             |    6 +++---
 sw/source/filter/ww8/writerhelper.hxx                    |    4 ++--
 sw/source/filter/ww8/ww8par2.cxx                         |    4 ++--
 12 files changed, 19 insertions(+), 19 deletions(-)

New commits:
commit a26b6c5a37408f49f81786ac1ba2ae9cef70d3d9
Author: Andrea Gelmini <andrea.gelm...@gelma.net>
Date:   Thu Nov 16 19:37:57 2017 +0100

    Fix typos
    
    Change-Id: I7b6c699b46fb71c1f19b5e5548c22a11efe8b864
    Reviewed-on: https://gerrit.libreoffice.org/44836
    Reviewed-by: Julien Nabet <serval2...@yahoo.fr>
    Tested-by: Julien Nabet <serval2...@yahoo.fr>

diff --git a/dbaccess/source/ui/browser/sbagrid.cxx 
b/dbaccess/source/ui/browser/sbagrid.cxx
index b97bcaa239fd..31939a46c5d1 100644
--- a/dbaccess/source/ui/browser/sbagrid.cxx
+++ b/dbaccess/source/ui/browser/sbagrid.cxx
@@ -576,7 +576,7 @@ void SbaGridHeader::dispose()
 void SbaGridHeader::StartDrag( sal_Int8 _nAction, const Point& _rPosPixel )
 {
     SolarMutexGuard aGuard;
-        // in the new DnD API, the solar mutex is not locked when StartDrag 
get's called
+        // in the new DnD API, the solar mutex is not locked when StartDrag is 
called
 
     ImplStartColumnDrag( _nAction, _rPosPixel );
 }
@@ -587,7 +587,7 @@ void SbaGridHeader::MouseButtonDown( const MouseEvent& 
_rMEvt )
         if (_rMEvt.GetClicks() != 2)
         {
             // the base class will start a column move here, which we don't 
want to allow
-            // (at the moment. If we store relative positions with the 
columns, we can allow column moves ....)
+            // (at the moment. If we store relative positions with the 
columns, we can allow column moves...)
 
         }
 
@@ -1023,7 +1023,7 @@ void SbaGridControl::MouseButtonDown( const 
BrowserMouseEvent& rMEvt)
 void SbaGridControl::StartDrag( sal_Int8 _nAction, const Point& _rPosPixel )
 {
     SolarMutexGuard aGuard;
-        // in the new DnD API, the solar mutex is not locked when StartDrag 
get's called
+        // in the new DnD API, the solar mutex is not locked when StartDrag is 
called
 
     bool bHandled = false;
 
diff --git a/dbaccess/source/ui/misc/WCPage.cxx 
b/dbaccess/source/ui/misc/WCPage.cxx
index 1b79ab76ed19..6f164463fda4 100644
--- a/dbaccess/source/ui/misc/WCPage.cxx
+++ b/dbaccess/source/ui/misc/WCPage.cxx
@@ -139,7 +139,7 @@ IMPL_LINK( OCopyTable, RadioChangeHdl, Button*, pButton, 
void )
     m_pCB_PrimaryColumn->Enable(bKey);
     m_pCB_UseHeaderLine->Enable(m_bUseHeaderAllowed && IsOptionDefData());
 
-    // set typ what to do
+    // set type what to do
     if( IsOptionDefData() )
         m_pParent->setOperation( CopyTableOperation::CopyDefinitionAndData );
     else if( IsOptionDef() )
diff --git a/embeddedobj/source/msole/oleembed.cxx 
b/embeddedobj/source/msole/oleembed.cxx
index 1b7d171f5074..e84871d5f304 100644
--- a/embeddedobj/source/msole/oleembed.cxx
+++ b/embeddedobj/source/msole/oleembed.cxx
@@ -538,7 +538,7 @@ void SAL_CALL OleEmbeddedObject::changeState( sal_Int32 
nNewState )
                         return;
                 }
 
-                // so now the object is either switched from Active to Running 
state or vise versa
+                // so now the object is either switched from Active to Running 
state or viceversa
                 // the notification about object state change will be done 
asynchronously
                 if ( m_nObjectState == embed::EmbedStates::RUNNING && 
nNewState == embed::EmbedStates::ACTIVE )
                 {
diff --git a/odk/examples/DevelopersGuide/Forms/ButtonOperator.java 
b/odk/examples/DevelopersGuide/Forms/ButtonOperator.java
index 2e15e774aa9b..890ea7251e70 100644
--- a/odk/examples/DevelopersGuide/Forms/ButtonOperator.java
+++ b/odk/examples/DevelopersGuide/Forms/ButtonOperator.java
@@ -85,7 +85,7 @@ public class ButtonOperator implements XActionListener, 
XFeatureInvalidation
     }
 
     /* ------------------------------------------------------------------ */
-    /** get's the button which we operate and which is responsible for a given 
URL
+    /** gets the button which we operate and which is responsible for a given 
URL
     */
     private XPropertySet getButton( short _formFeature )
     {
diff --git a/odk/examples/DevelopersGuide/Forms/FLTools.java 
b/odk/examples/DevelopersGuide/Forms/FLTools.java
index 8d538d6afb12..ea1467b52adb 100644
--- a/odk/examples/DevelopersGuide/Forms/FLTools.java
+++ b/odk/examples/DevelopersGuide/Forms/FLTools.java
@@ -130,7 +130,7 @@ public class FLTools
     }
 
     /* ------------------------------------------------------------------ */
-    /** get's the XControlModel for a control
+    /** gets the XControlModel for a control
     */
     public static <T> T getModel( Object aControl, Class<T> aInterfaceClass )
     {
diff --git a/odk/examples/java/Text/BookmarkInsertion.java 
b/odk/examples/java/Text/BookmarkInsertion.java
index d2f158eba42f..a857b36c2874 100644
--- a/odk/examples/java/Text/BookmarkInsertion.java
+++ b/odk/examples/java/Text/BookmarkInsertion.java
@@ -183,7 +183,7 @@ public class BookmarkInsertion {
 
             xTextCursor.setString( "He heard quiet steps behind him. That 
didn't bode well. Who could be following him this late at night and in this 
deadbeat part of town? And at this particular moment, just after he pulled off 
the big time and was making off with the greenbacks. Was there another crook 
who'd had the same idea, and was now watching him and waiting for a chance to 
grab the fruit of his labor?" );
             xTextCursor.collapseToEnd();
-            xTextCursor.setString( "Or did the steps behind him mean that one 
of many bloody officers in town was on to him and just waiting to pounce and 
snap those cuffs on his wrists? He nervously looked all around. Suddenly he saw 
the alley. Like lightening he darted off to the left and disappeared between 
the two warehouses almost falling over the trash can lying in the middle of the 
sidewalk. He tried to nervously tap his way along in the inky darkness and 
suddenly stiffened: it was a dead-end, he would have to go back the way he had 
come" );
+            xTextCursor.setString( "Or did the steps behind him mean that one 
of many bloody officers in town was on to him and just waiting to pounce and 
snap those cuffs on his wrists? He nervously looked all around. Suddenly he saw 
the alley. Like lightning he darted off to the left and disappeared between the 
two warehouses almost falling over the trash can lying in the middle of the 
sidewalk. He tried to nervously tap his way along in the inky darkness and 
suddenly stiffened: it was a dead-end, he would have to go back the way he had 
come" );
             xTextCursor.collapseToEnd();
             xTextCursor.setString( "The steps got louder and louder, he saw 
the black outline of a figure coming around the corner. Is this the end of the 
line? he thought pressing himself back against the wall trying to make himself 
invisible in the dark, was all that planning and energy wasted? He was dripping 
with sweat now, cold and wet, he could smell the brilliant fear coming off his 
clothes. Suddenly next to him, with a barely noticeable squeak, a door swung 
quietly to and fro in the night's breeze." );
 
diff --git a/qadevOOo/runner/util/utils.java b/qadevOOo/runner/util/utils.java
index b8134f0a630d..a0f525ab8339 100644
--- a/qadevOOo/runner/util/utils.java
+++ b/qadevOOo/runner/util/utils.java
@@ -195,7 +195,7 @@ public class utils {
 
     /**
      *
-     * This method get's the user dir of the connected office
+     * This method gets the user dir of the connected office
      *
      */
     public static String getOfficeUserPath(XMultiServiceFactory msf) {
@@ -258,7 +258,7 @@ public class utils {
 
     /**
      *
-     * This method get's the temp dir of the connected office
+     * This method gets the temp dir of the connected office
      *
      */
     public static String getOfficeTemp(XMultiServiceFactory msf) {
diff --git a/qadevOOo/tests/java/ifc/sheet/_TableAutoFormatField.java 
b/qadevOOo/tests/java/ifc/sheet/_TableAutoFormatField.java
index 1edec3b1c9e8..305d3e219371 100644
--- a/qadevOOo/tests/java/ifc/sheet/_TableAutoFormatField.java
+++ b/qadevOOo/tests/java/ifc/sheet/_TableAutoFormatField.java
@@ -78,7 +78,7 @@ public class _TableAutoFormatField extends MultiPropertyTest {
     /**
     * Only some values can be used (which identify font name).
     * In this property value is changed from 'Times New Roman'
-    * to 'Courier' and vise versa.
+    * to 'Courier' and viceversa.
     */
     public void _CharFontName() {
         testProperty("CharFontName", new PropertyTester() {
diff --git a/starmath/source/mathmlimport.cxx b/starmath/source/mathmlimport.cxx
index 120b0849000b..e1537bf62d75 100644
--- a/starmath/source/mathmlimport.cxx
+++ b/starmath/source/mathmlimport.cxx
@@ -2264,7 +2264,7 @@ SvXMLImportContextRef 
SmXMLDocContext_Impl::CreateChildContext(
                 rLocalName);
             break;
         default:
-            /*Basically theres an implicit mrow around certain bare
+            /*Basically there's an implicit mrow around certain bare
              *elements, use a RowContext to see if this is one of
              *those ones*/
             rtl::Reference<SmXMLRowContext_Impl> aTempContext(new 
SmXMLRowContext_Impl(GetSmImport(),nPrefix,
diff --git a/starmath/source/mathtype.cxx b/starmath/source/mathtype.cxx
index 012d0c74087f..f179b54f2e0d 100644
--- a/starmath/source/mathtype.cxx
+++ b/starmath/source/mathtype.cxx
@@ -592,7 +592,7 @@ bool MathType::Parse(SotStorage *pStor)
 #ifdef CAOLAN
     //sanity check
 
-    //sigh, theres no point! MathType (in some bizarre subvarient) pads
+    //sigh, there's no point! MathType (in some bizarre subvarient) pads
     //the end of the formula with ENDs (0)'s
     auto nEnd = pS->Tell();
     SAL_WARN_IF(nEnd == pS->Seek(STREAM_SEEK_TO_END), "starmath", "Possibly 
unfully parsed formula");
@@ -2057,7 +2057,7 @@ int MathType::StartTemplate(sal_uInt16 
nSelector,sal_uInt16 nVariation)
     pS->WriteUChar( nVariation ); //variation
     pS->WriteUChar( 0x00 ); //options
     pS->WriteUChar( LINE );
-    //theres just no way we can now handle any character
+    //there's just no way we can now handle any character
     //attributes (from mathtypes perspective) centered
     //over an expression but above template attribute
     //such as widevec and similar constructs
@@ -3176,7 +3176,7 @@ void MathType::HandleAttributes(SmNode *pNode,int nLevel)
         switch (pTemp->GetToken().eType)
         {
         case TWIDEVEC:
-            //theres just no way we can now handle any character
+            //there's just no way we can now handle any character
             //attributes (from mathtypes perspective) centered
             //over an expression but above template attributes
             //such as widevec and similar constructs
diff --git a/sw/source/filter/ww8/writerhelper.hxx 
b/sw/source/filter/ww8/writerhelper.hxx
index cf6e379df9ec..27dbd1b7b13c 100644
--- a/sw/source/filter/ww8/writerhelper.hxx
+++ b/sw/source/filter/ww8/writerhelper.hxx
@@ -540,7 +540,7 @@ namespace sw
 
             There are two differing types of numbering formats that may be on a
             paragraph, normal and outline. The outline is that numbering you
-            see in tools->outline numbering. Theres no difference in the
+            see in tools->outline numbering. There's no difference in the
             numbering itself, just how you get it from the SwTextNode. Needless
             to say the filter generally couldn't care less what type of
             numbering is in use.
@@ -574,7 +574,7 @@ namespace sw
 
             There are two differing types of numbering formats that may be on a
             paragraph, normal and outline. The outline is that numbering you
-            see in tools->outline numbering. Theres no difference in the
+            see in tools->outline numbering. There's no difference in the
             numbering itself, just how you get it from the SwTextNode. Needless
             to say the filter generally couldn't care less what type of
             numbering is in use.
diff --git a/sw/source/filter/ww8/ww8par2.cxx b/sw/source/filter/ww8/ww8par2.cxx
index dfc1eaddb984..5a7c740e8c3b 100644
--- a/sw/source/filter/ww8/ww8par2.cxx
+++ b/sw/source/filter/ww8/ww8par2.cxx
@@ -2684,7 +2684,7 @@ void WW8TabDesc::MergeCells()
                         // declared invalid because of sharing the exact same 
dimensions
                         // as their previous cell
 
                         //If theres anything underneath/above we're ok.
                         if (rCell.bVertMerge || rCell.bVertRestart)
                             bMerge = true;
                         else
@@ -4086,7 +4086,7 @@ void WW8RStyle::PostProcessStyles()
 
     /*
      In the same loop apply the tabstop changes required because we need to
-     change their location if theres a special indentation for the first line,
+     change their location if there's a special indentation for the first line,
      By avoiding making use of each styles margins during reading of their
      tabstops we don't get problems with doubly adjusting tabstops that
      are inheritied.
@@ -2684,7 +2684,7 @@ void WW8TabDesc::MergeCells()
                         // as their previous cell
 
-                        //If theres anything underneath/above we're ok.
+                        //If there's anything underneath/above we're ok.
                         if (rCell.bVertMerge || rCell.bVertRestart)
                             bMerge = true;
_______________________________________________
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits

Reply via email to